homology.PersDiag.bin — GDA Toolbox v1.0 Manual

# homology.PersDiag.bin

`PersDiag.` `bin`(width, underflow=None, overflow=None, transform='project')

  Count bins on the transformed persistence diagram. Bins are added for (-inf, underflow] and (overflow,inf). If underflow and overflow are not provided, they are set to min/max.

  NOTE! The bin_count numbers look “upside-down and backwards” versus the projected persistence diagram. This is because indexing of a matrix is from the top, whereas we read pictures from the bottom.

  return:
    bin_count (2-dim np array of bin counts), bin_boundaries

#### Previous topic

homology.PersDiag

#### Next topic

homology.PersDiag.bin_bot